@@ -8,32 +8,32 @@ use Carp;
 use PerlIO::gzip;
 use Lingua::YALI;
 
-our $VERSION = '0.010_03'; # VERSION
+our $VERSION = '0.010_04'; # VERSION
 
 # hash with paths to models
 # format: { 'class1' => 'file1', 'class2' => 'file2' }
-has '_model_file' => ( 
-    is => 'rw', 
-    isa => 'HashRef' 
+has '_model_file' => (
+    is => 'rw',
+    isa => 'HashRef'
     );
 
 # hash with n-gram frequencies retrieved from models
 # format: { 'ngram1' => { 'class1' => 0.5, 'class2' => 0.3}, 'ngram2' => ...}
-has '_frequency' => ( 
-    is => 'rw', 
-    isa => 'HashRef' 
+has '_frequency' => (
+    is => 'rw',
+    isa => 'HashRef'
     );
 
 # n-gram size
-has '_ngram' => ( 
-    is => 'rw', 
-    isa => 'Int' 
+has '_ngram' => (
+    is => 'rw',
+    isa => 'Int'
     );
 
 # list of identified classes
-has '_classes' =>  ( 
-    is => 'rw', 
-    isa => 'ArrayRef' 
+has '_classes' =>  (
+    is => 'rw',
+    isa => 'ArrayRef'
     );
 
 
@@ -93,14 +93,15 @@ sub get_classes
     return $self->{_classes};
 }
 
+
 sub identify_file
 {
     my ( $self, $file ) = @_;
-    
+
     if ( ! defined($file) ) {
         return;
     }
-    
+
     my $fh = Lingua::YALI::_open($file);
 
     return $self->identify_handle($fh);
@@ -115,7 +116,7 @@ sub identify_string
     if ( ! defined($string) ) {
         return;
     }
-
+    
     my $result = $self->identify_handle($fh);
 
     close($fh);
@@ -123,24 +124,25 @@ sub identify_string
     return $result;
 }
 
+
 sub identify_handle
 {
     my ($self, $fh, $verbose) = @_;
     my %actRes = ();
 
+    # parameter check
+    my $ngram = $self->{_ngram};
+    if ( ! defined($ngram) ) {
+        croak("At least one class must be specified.");
+    }
+
     if ( ! defined($fh) ) {
         return;
     } elsif ( ref $fh ne "GLOB" ) {
         croak("Expected file handler but " . (ref $fh) . " was used.");
     }
 
-#    my $padding = $self->{_padding};
-    my $ngram = $self->{_ngram};
-
-    if ( ! defined($ngram) ) {
-        croak("At least one class must be specified.");
-    }
-
+    # read input file
     while ( <$fh> ) {
         chomp;
         s/ +/ /g;
@@ -166,9 +168,9 @@ sub identify_handle
                 }
             }
         }
-
     }
 
+    # sum scores of all classifiers
     my @allLanguages = @ { $self->get_classes() };
 
     my $sum = 0;
@@ -180,6 +182,7 @@ sub identify_handle
         $sum += $score;
     }
 
+    # normalize results
     my @res = ();
     if ( $sum > 0 ) {
         for my $l (@allLanguages) {
@@ -199,19 +202,24 @@ sub identify_handle
 #    print STDERR "\nY\n\t" . $res[1]->[0] . "\nY\n";
 #    print STDERR "\nY\n\t" . $res[1]->[1] . "\nY\n";
 
+    # sort according to score
     my @sortedRes = sort { $b->[1] <=> $a->[1] } @res;
 
     return \@sortedRes;
 }
 
+# recompute classes after manipulation with classes
 sub _compute_classes
 {
     my $self    = shift;
     my @classes = keys %{ $self->{_model_file} };
 
     $self->{_classes} = \@classes;
+
+    return;
 }
 
+# load model
 sub _load_model
 {
     my ($self, $class, $file) = @_;
@@ -250,11 +258,12 @@ sub _load_model
     close($fh);
 
     $self->{_model_file}->{$class} = $file;
-    $self->_compute_classes();   
+    $self->_compute_classes();
 
     return;
 }
 
+# unload model
 sub _unload_model
 {
     my ($self, $class) = @_;
@@ -263,7 +272,7 @@ sub _unload_model
         return;
     }
 
-    delete( $self->{_model_file}->{$class} );   
+    delete( $self->{_model_file}->{$class} );
     $self->_compute_classes();
 
     my $classes = $self->get_classes();
@@ -271,9 +280,9 @@ sub _unload_model
     if ( scalar @$classes == 0 ) {
         delete($self->{_ngram});
         $self->{_ngram} = undef;
-    }    
-    
-    
+    }
+
+
 
 
     return;
@@ -291,7 +300,7 @@ Lingua::YALI::Identifier - Module for language identification with custom models
 
 =head1 VERSION
 
-version 0.010_03
+version 0.010_04
 
 =head1 SYNOPSIS
 
@@ -301,7 +310,7 @@ Models trained on texts from specific domain outperforms the general ones.
 
     use Lingua::YALI::Builder;
     use Lingua::YALI::Identifier;
-    
+
     # create models
     my $builder_a = Lingua::YALI::Builder->new(ngrams=>[2]);
     $builder_a->train_string("aaaaa aaaa aaa aaa aaa aaaaa aa");
@@ -320,7 +329,7 @@ Models trained on texts from specific domain outperforms the general ones.
     my $result1 = $identifier->identify_string("aaaaaaaaaaaaaaaaaaa");
     print $result1->[0]->[0] . "\t" . $result1->[0]->[1];
     # prints out a 1
-    
+
     my $result2 = $identifier->identify_string("bbbbbbbbbbbbbbbbbbb");
     print $result2->[0]->[0] . "\t" . $result2->[0]->[1];
     # prints out b 1
@@ -343,7 +352,7 @@ Initializes internal variables.
 Adds model stored in file C<$model> with class C<$class> and
 returns whether it was added or not.
 
-    print $identifier->add_class("a", "model.a1.gz") . "\n"; 
+    print $identifier->add_class("a", "model.a1.gz") . "\n";
     # prints out 1
     print $identifier->add_class("a", "model.a2.gz") . "\n";
     # prints out 0 - class a was already added
@@ -355,10 +364,10 @@ returns whether it was added or not.
 Removes model for class C<$class>.
 
     $identifier->add_class("a", "model.a1.gz");
-    print $identifier->remove_class("a") . "\n"; 
+    print $identifier->remove_class("a") . "\n";
     # prints out 1
     print $identifier->remove_class("a") . "\n";
-    # prints out 0 - class a was already removed     
+    # prints out 0 - class a was already removed
 
 =head2 get_classes
 
@@ -408,7 +417,7 @@ Identifies class for file handle C<$fh> and returns:
 
 =item * It croaks if the C<$fh> is not file handle.
 
-=item * It returns array reference in format [ ['class1', score1], ['class2', score2], ...] sorted 
+=item * It returns array reference in format [ ['class1', score1], ['class2', score2], ...] sorted
 according to score descendently, so the most probable class is the first.
 
 =back
